/** ###################################################################
**     THIS COMPONENT MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename  : TZG.c
**     Project   : ______PWM
**     Processor : MC9S12XS128MAA
**     Component : PWM
**     Version   : Component 02.231, Driver 01.16, CPU db: 3.00.019
**     Compiler  : CodeWarrior HCS12X C Compiler
**     Date/Time : 2011/6/14, 10:52
**     Abstract  :
**         This component implements a pulse-width modulation generator
**         that generates signal with variable duty and fixed cycle. 
**     Settings  :
**         Used output pin             : 
**             ----------------------------------------------------
**                Number (on package)  |    Name
**             ----------------------------------------------------
**                       3             |  PP1_KWP1_PWM1_IOC1
**             ----------------------------------------------------
**
**         Timer name                  : PWM01 [16-bit]
**         Counter                     : PWMCNT01  [$030C]
**         Mode register               : PWMCTL    [$0305]
**         Run register                : PWME      [$0300]
**         Prescaler                   : PWMPRCLK  [$0303]
**         Compare 1 register          : PWMPER01  [$0314]
**         Compare 2 register          : PWMDTY01  [$031C]
**         Flip-flop 1 register        : PWMPOL    [$0301]
**
**         User handling procedure     : not specified
**
**         Output pin
**
**         Port name                   : P
**         Bit number (in port)        : 1
**         Bit mask of the port        : $0002
**         Port data register          : PTP       [$0258]
**         Port control register       : DDRP      [$025A]
**
**         Runtime setting period      : none
**         Runtime setting ratio       : calculated
**         Initialization:
**              Aligned                : Left
**              Output level           : high
**              Timer                  : Enabled
**              Event                  : Enabled
**         High speed mode
**             Prescaler               : divide-by-1
**             Clock                   : 8000000 Hz
**           Initial value of            period        pulse width (ratio 68.18%)
**             Xtal ticks              : 88            60
**             microseconds            : 6             4
**             seconds (real)          : 0.0000055     0.00000375
**
**     Contents  :
**         SetRatio16 - byte TZG_SetRatio16(word Ratio);
**         SetDutyUS  - byte TZG_SetDutyUS(word Time);
**
**     Copyright : 1997 - 2010 Freescale Semiconductor, Inc. All Rights Reserved.
**     
**     http      : www.freescale.com
**     mail      : support@freescale.com
** ###################################################################*/


/* MODULE TZG. */

#include "TZG.h"

#pragma DATA_SEG TZG_DATA              /* Select data segment "TZG_DATA" */

#pragma CODE_SEG TZG_CODE

static word RatioStore;                /* Ratio of L-level to H-level */


/*
** ===================================================================
**     Method      :  SetRatio (component PWM)
**
**     Description :
**         The method reconfigures the compare and modulo registers of 
**         the peripheral(s) when the speed mode changes. The method is 
**         called automatically as a part of the component 
**         SetHigh/SetLow/SetSlow methods.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
#pragma MESSAGE DISABLE C12056         /* Disable WARNING C12056: SP debug info incorrect because of optimization */
static void SetRatio(void)
{
  /* Calculate new value according to the given ratio: PWMDTY01 = (PWMPER01 * (dword)RatioStore + 0x8000) / 0xFFFF; */
  /*lint -save  -e950 Disable MISRA rule (1.1) checking. */
  asm {
    LDY    PWMPER01
    LDD    RatioStore
    EMUL
    ADDD   #32768
    EXG    D,Y
    ADCB   #0
    ADCA   #0
    LDX    #0xFFFF
    EXG    D,Y
    EDIV
    STY    PWMDTY01
  };
  /*lint -restore Enable MISRA rule (1.1) checking. */
}
#pragma MESSAGE DEFAULT C12056         /* Re-enable WARNING C12056 */

/*
** ===================================================================
**     Method      :  TZG_SetRatio16 (component PWM)
**
**     Description :
**         This method sets a new duty-cycle ratio. Ratio is expressed
**         as a 16-bit unsigned integer number. Value 0 - 65535 value
**         is proportional to ratio 0 - 100%. 
**         Note: Calculated duty depends on the timer possibilities and
**         on the selected period.
**         The method is available only if method <SetPeriodMode> is
**         not selected.
**     Parameters  :
**         NAME            - DESCRIPTION
**         Ratio           - Ratio to set. 0 - 65535 value is
**                           proportional to ratio 0 - 100%
**     Returns     :
**         ---             - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
** ===================================================================
*/
byte TZG_SetRatio16(word Ratio)
{
  RatioStore = Ratio;                  /* Store new value of the ratio */
  /*lint -save  -e522 Disable MISRA rule (14.2) checking. */
  SetRatio();                          /* Calculate and set up new appropriate values of the duty and period registers */
  /*lint -restore Enable MISRA rule (14.2) checking. */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  TZG_SetDutyUS (component PWM)
**
**     Description :
**         This method sets the new duty value of the output signal. The
**         duty is expressed in microseconds as a 16-bit unsigned integer
**         number.
**     Parameters  :
**         NAME       - DESCRIPTION
**         Time       - Duty to set [in microseconds]
**                      (0 to 6 us in high speed mode)
**     Returns     :
**         ---        - Error code, possible codes:
**                           ERR_OK - OK
**                           ERR_SPEED - This device does not work in
**                           the active speed mode
**                           ERR_MATH - Overflow during evaluation
**                           ERR_RANGE - Parameter out of range
** ===================================================================
*/
byte TZG_SetDutyUS(word Time)
{
  dlong rtval;                         /* Result of two 32-bit numbers multiplication */

  if (Time > 0x06U) {                  /* Is the given value out of range? */
    return ERR_RANGE;                  /* If yes then error */
  }
  PE_Timer_LngMul((dword)Time, (dword)780903145, &rtval); /* Multiply given value and high speed CPU mode coefficient */
  if (PE_Timer_LngHi2(rtval[0], rtval[1], &RatioStore)) { /* Is the result greater or equal than 65536 ? */
    RatioStore = 0xFFFFU;              /* If yes then use maximal possible value */
  }
  /*lint -save  -e522 Disable MISRA rule (14.2) checking. */
  SetRatio();                          /* Calculate and set up new appropriate values of the duty and period registers */
  /*lint -restore Enable MISRA rule (14.2) checking. */
  return ERR_OK;                       /* OK */
}

/*
** ===================================================================
**     Method      :  TZG_Init (component PWM)
**
**     Description :
**         Initializes the associated peripheral(s) and the component's 
**         internal variables. The method is called automatically as a 
**         part of the application initialization code.
**         This method is internal. It is used by Processor Expert only.
** ===================================================================
*/
void TZG_Init(void)
{
  /* PWMCNT01: PWMCNT01=0 */
  setReg16(PWMCNT01, 0x00U);           /* Reset Counter */ 
  /* PWMSDN: PWMIF=1,PWMIE=0,PWMRSTRT=0,PWMLVL=0,??=0,PWM7IN=0,PWM7INL=0,PWM7ENA=0 */
  setReg8(PWMSDN, 0x80U);              /* Emergency shutdown feature settings */ 
  RatioStore = 0xAE8BU;                /* Store initial value of the ratio */
  /* PWMDTY01: PWMDTY01=0x1E */
  setReg16(PWMDTY01, 0x1EU);           /* Store initial value to the duty-compare register */ 
  /* PWMPER01: PWMPER01=0x2C */
  setReg16(PWMPER01, 0x2CU);           /* and to the period register */ 
  /* PWMPRCLK: ??=0,PCKB2=0,PCKB1=0,PCKB0=0,??=0,PCKA2=0,PCKA1=0,PCKA0=0 */
  setReg8(PWMPRCLK, 0x00U);            /* Set prescaler register */ 
  /* PWMSCLA: BIT7=0,BIT6=0,BIT5=0,BIT4=0,BIT3=0,BIT2=0,BIT1=0,BIT0=1 */
  setReg8(PWMSCLA, 0x01U);             /* Set scale register */ 
  /* PWMCLK: PCLK1=0 */
  clrReg8Bits(PWMCLK, 0x02U);          /* Select clock source */ 
  /* PWME: PWME1=1 */
  setReg8Bits(PWME, 0x02U);            /* Run counter */ 
}

/* END TZG. */

/*
** ###################################################################
**
**     This file was created by Processor Expert 3.02 [04.44]
**     for the Freescale HCS12X series of microcontrollers.
**
** ###################################################################
*/
